clipped_on

Function clipped_on 

fn clipped_on(shell: &Shell, native: &Event, id: CommandId)
A copy or a cut anywhere but a field takes the selection, when there is one to take — and is otherwise left to the browser.