fn kept_by_a_control(native: &KeyboardEvent) -> boolExpand description
Whether a control took the key. A menu takes Escape — and says so even while it is closed, when there is nothing for it to close; the key is then the drawing’s.
fn kept_by_a_control(native: &KeyboardEvent) -> boolWhether a control took the key. A menu takes Escape — and says so even while it is closed, when there is nothing for it to close; the key is then the drawing’s.