fn keyed(shell: &Shell, native: &KeyboardEvent, edge: Edge)Expand description
A keystroke the canvas reads, or a chord this call has a command for. Everything else is left to the browser.
fn keyed(shell: &Shell, native: &KeyboardEvent, edge: Edge)A keystroke the canvas reads, or a chord this call has a command for. Everything else is left to the browser.