pub fn install()Expand description
Install the console and the Performance panel as the one subscriber: debug and up in a debug build, info and up otherwise.
pub fn install()Install the console and the Performance panel as the one subscriber: debug and up in a debug build, info and up otherwise.