pub enum Schedule {
Idle,
Frame,
Timer {
ticket: Ticket,
after: Duration,
},
}Expand description
What the shell should book.
Variants
Idle
Nothing: a frame is already booked, or none is owed.
Frame
The next animation frame, which is the soonest a frame can run.
Timer
A frame after after, which is longer than the browser’s next frame.